@@ -10,6 +10,10 @@ describe Prawn::SVG::Attributes::Transform do
       @warnings = []
       @attributes = {}
     end
+
+    def transformable?
+      true
+    end
   end
 
   let(:element) { TransformTestElement.new }
@@ -20,7 +24,8 @@ describe Prawn::SVG::Attributes::Transform do
     let(:transform) { 'translate(-5.5)' }
 
     it 'passes the transform and executes the returned matrix' do
-      expect(element).to receive(:parse_transform_attribute).with(transform).and_return([1, 2, 3, 4, 5, 6])
+      expect(element).to receive(:parse_transform_attribute).with(transform)
+      expect(element).to receive(:matrix_for_pdf).and_return([1, 2, 3, 4, 5, 6])
       expect(element).to receive(:add_call_and_enter).with('transformation_matrix', 1, 2, 3, 4, 5, 6)
 
       element.attributes['transform'] = transform
@@ -32,7 +37,8 @@ describe Prawn::SVG::Attributes::Transform do
     let(:transform) { 'translate(0)' }
 
     it 'does not execute any commands' do
-      expect(element).to receive(:parse_transform_attribute).with(transform).and_return([1, 0, 0, 1, 0, 0])
+      expect(element).to receive(:parse_transform_attribute).with(transform)
+      expect(element).to receive(:matrix_for_pdf).and_return([1, 0, 0, 1, 0, 0])
       expect(element).not_to receive(:add_call_and_enter)
 
       element.attributes['transform'] = transform
@@ -43,6 +49,7 @@ describe Prawn::SVG::Attributes::Transform do
   context 'when transform is blank' do
     it 'does nothing' do
       expect(element).not_to receive(:parse_transform_attribute)
+      expect(element).not_to receive(:matrix_for_pdf)
       expect(element).not_to receive(:add_call_and_enter)
 
       subject
